<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="tr" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Hakkında</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Torrent'i başlat</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Adresleme denetimini atla</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Alt klasör oluştur</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrent Yönetim Kipi:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Kategorilenmemiş</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Kategori ekle...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Kategoriyi kaldır</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Kullanılmayan kategorileri kaldır</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrent'lere devam et</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrent'leri duraklat</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrent'leri sil</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Yeni Kategori</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Kategoriyi düzenle...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>qBittorrent'ten Çık</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Her satıra sadece bir bağlantı</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Genel gönderme oranı sınırı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Genel indirme oranı sınırı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatif gönderme oranı sınırı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatif indirme oranı sınırı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>En fazla aktif indirme -1'den büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>En fazla aktif gönderme -1'den büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>En fazla aktif torrent -1'den büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>En fazla bağlantı sınırı sayısı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Torrent başına en fazla bağlantı sınırı sayısı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Torrent başına en fazla gönderme yuvası sınırı sayısı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Program tercihleri kaydedilemiyor, qBittorrent'e muhtemelen ulaşılamıyor.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: Freenode üzerinde #qbittorrent kanalı</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Bilinmiyor</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Paylaşma oranı sınırı 0 ve 9998 arasında olmak zorundadır.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Gönderim süresi sınırı 0 ve 525600 dakika arasında olmak zorundadır.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Gelen bağlantılar için kullanılan bağlantı noktası 1 ve 65535 arasında olmak zorundadır.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Web Arayüzü için kullanılan bağlantı noktası 1 ve 65535 arasında olmak zorundadır.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Oturum açılamıyor, qBittorrent'e muhtemelen ulaşılamıyor.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Geçersiz Kullanıcı Adı veya Parola.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Oturum Aç</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Orijinal hazırlayanları</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Torrent'leri Gönder</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Dosyaların kaydedildiği yer:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Tanımlama Bilgisi:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Klasörü buraya yazın</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Daha fazla bilgi</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Sertifikalar hakkında bilgiler</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Yeri ayarla</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Gönderme oranını sınırla</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>İndirme oranını sınırla</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Torrent'i yeniden adlandır</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Diğer...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pazartesi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Salı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pazar</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Oturumu Kapat</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Torrent'leri URL'lerinden ya da Magnet bağlantılarından indir</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Yerel torrent'i gönder</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Seçilen torrent'leri aktarım listesinden silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent istemcisine ulaşılamıyor</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Genel gönderme yuvası sınırı 0'dan büyük olmak ya da etkisizleştirilmek zorundadır.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Geçersiz kategori adı:\nLütfen kategori adı içinde hiçbir özel karakter kullanmayın.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kategori oluşturulamıyor</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Gönderme oranı eşiği 0'dan büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Boş alan: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrent boşta durma zamanlayıcısı 0'dan büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Kaydetme Yönetimi</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>İndirme oranı eşiği 0'dan büyük olmak zorundadır.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent kapatıldı</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation>Belgeleri aç</translation>
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation>Magnet bağlantılarını işlemek için kaydettir...</translation>
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation>Kişi eklenemiyor. Lütfen IP:b.noktası biçimine bağlı kaldığınızdan emin olun.</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation>JavaScript Gerekli! Web Arayüzünün düzgün çalışması için JavaScript'i etkinleştirmek zorundasınız</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Araçlar</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Dosya</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Seçenekler...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Devam</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Üst Araç Çubuğu</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Durum Çubuğu</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Başlık Çubuğunda Hızı Göster</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Bağış Yap!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Tümüne Devam</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>İstatistikler</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Tümünü Duraklat</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Torrent Dosyası Ekle...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Torrent Bağlantısı Ekle...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Genel Gönderme Hızı Sınırı</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Genel İndirme Hızı Sınırı</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>qBittorrent uygulamasından çıkmak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[İnd: %1, Gön: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatif hız sınırları</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Arama Motoru</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Torrent listesini süzün...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Aktarımlar</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation>Kuyrukta yukarı taşı</translation>
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation>Kuyruk Yukarı Taşı</translation>
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation>Kuyruğun En Altına</translation>
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation>Kuyruğun en altına taşı</translation>
    </message>
    <message>
        <source>Top of Queue</source>
        <translation>Kuyruğun En Üstüne</translation>
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation>Kuyruk Aşağı Taşı</translation>
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation>Kuyrukta aşağı taşı</translation>
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation>Kuyruğun en üstüne taşı</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>İndirmeler</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Bağlantı</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hız</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web Arayüzü</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Dil</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Kullanıcı Arayüzü Dili:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>İndirmenin tamamlanması üzerine e-posta bildirimi yap</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Torrent tamamlanmasında harici program çalıştır</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP Süzme</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Alternatif oran sınırları kullanımını zamanla</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrent Kuyruğu</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Bu izleyicileri otomatik olarak yeni indirmelere ekle:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Web Kullanıcı Arayüzü (Uzak denetim)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP adresi:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Sunucu etki alanları:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTP yerine HTTPS kullan</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Yerel makinedeki istemciler için kimlik doğrulamasını atlat</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Beyaz listeye alınmış IP alt ağlarındaki istemciler için kimlik doğrulamasını atlat</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Değişken etki alanı adımı güncelle</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Tamamlanmamış torrent'leri şurada tut:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>.torrent dosyalarını şuraya kopyala:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Tamamlanan indirmeler için .torrent dosyalarını şuraya kopyala:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Tüm dosyalar için disk alanını önceden ayır</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Tamamlanmamış dosyalara .!qB uzantısı ekle</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Torrent'leri otomatik olarak şuradan ekle:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP sunucusu:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Bu sunucu güvenli bir bağlantı gerektirir (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Kimlik Doğrulaması</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Etkinleştirilmiş protokol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP ve μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Dinlenen Bağlantı Noktası</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Gelen bağlantılar için kullanılan b.noktası:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Yönlendiricimden UPnP / NAT-PMP bağlantı noktası yönlendirmesi kullan</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Her başlangıçta farklı bağlantı noktası kullan</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Bağlantı Sınırları</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Torrent başına en fazla bağlantı sayısı:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Genel en fazla bağlantı sayısı:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Torrent başına en fazla gönderme yuvası sayısı:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Genel en fazla gönderme yuvası sayısı:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proksi Sunucusu</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Türü:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Yok)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Anamakine:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>B.Noktası:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Kişi bağlantıları için proksi kullan</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Sadece torrent'ler için proksi kullan</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Süzgeç yolu (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>El ile yasaklanan IP adresleri...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>İzleyicilere uygula</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Genel Oran Sınırları</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Gönderme:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>İndirme:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatif Oran Sınırları</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Buradan:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Buraya:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Zaman:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Her gün</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Hafta içi</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Hafta sonu</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Oran Sınırı Ayarları</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Oran sınırını aktarım ekyüküne uygula</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Oran sınırını µTP protokolüne uygula</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Gizlilik</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Daha çok kişi bulmak için DHT'yi (merkezsizleştirilmiş ağ) etkinleştir</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Daha çok kişi bulmak için Kişi Değişimi'ni (PeX) etkinleştir</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Daha çok kişi bulmak için Yerel Kişi Keşfi'ni etkinleştir</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Şifreleme kipi:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Şifreleme gerekir</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Şifrelemeyi etkisizleştir</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>İsimsiz kipi etkinleştir</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>En fazla aktif indirme:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>En fazla aktif gönderme:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>En fazla aktif torrent:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Yavaş torrent'leri bu sınırlar içinde sayma</translation>
    </message>
    <message>
        <source>then</source>
        <translation>ardından</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Yönlendiricimden bağlantı noktasını yönlendirmek için UPnP / NAT-PMP kullan</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Sertifika:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Anahtar:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Kaydol</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Etki alanı adı:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Desteklenen parametreler (büyük küçük harfe duyarlı):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrent adı</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategori</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: İçerik yolu (çok dosyalı torrent için olan kök yolu ile aynı)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Kök yolu (ilk torrent alt dizin yolu)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Kaydetme yolu</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Dosya sayısı</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrent boyutu (bayt)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Şu anki izleyici</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Bilgi adreslemesi</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>İpucu: Metnin boşluktan kesilmesini önlemek için parametreyi tırnak işaretleri arasına alın (örn., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Web Arayüzü kullanıcı adı en az 3 karakter uzunluğunda olmak zorundadır.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Web Arayüzü parolası en az 6 karakter uzunluğunda olmak zorundadır.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>dakika</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Tıklama suistimali (clickjacking) korumasını etkinleştir</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Siteler Arası İstek Sahteciliği (CSRF) korumasını etkinleştir</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Sonrasında .torrent dosyalarını sil</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>İndirme oranı eşiği:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Gönderme oranı eşiği:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Şu anki parolayı değiştir</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Otomatik</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Alternatif Web Arayüzü kullan</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Varsayılan Kaydetme Yolu:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Alternatif Web Arayüzü dosyaları konumu boş olamaz.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>İndirmeyi otomatik olarak başlatma</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Torrent'i Elle Kipine değiştir</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Torrent Kategorisi değiştiğinde:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Etkilenmiş torrent'lerin yerini değiştir</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Oran sınırını LAN üzerindeki kişilere uygula</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 sınırsız anlamına gelir</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Torrent'in yerini değiştir</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Varsayılan Kaydetme Yolu değiştiğinde:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Anamakine üstbilgi doğrulamasını etkinleştir</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Güvenlik</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Kategori Kaydetme Yolu değiştiğinde:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Çoklu dosyaları olan torrent'ler için alt klasör oluştur</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>saniye</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Etkilenmiş torrent'leri Elle Kipine değiştir</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Dosyalar konumu:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Elle</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrent boşta durma zamanlayıcısı:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Varsayılan Torrent Yönetim Kipi:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Bir torrent eklerken</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation>Bilgi: Parola şifrelenmeden kaydedilir</translation>
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation>Değişmez süper gönderim:</translation>
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation>μTP-TCP karışık kip algoritması:</translation>
    </message>
    <message>
        <source>Upload rate based</source>
        <translation>Gönderme oranına dayalı</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation>%G: Etiketler (virgülle ayırın)</translation>
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation>Soket biriktirme listesi boyutu:</translation>
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation>Torrent için süper gönderimi etkinleştir</translation>
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation>TCP tercih et</translation>
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation>Torrent'ler denetlenirken bekleyen bellek:</translation>
    </message>
    <message>
        <source>Anti-leech</source>
        <translation>Sömürü önleyici</translation>
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation>İS önbelleğini etkinleştir:</translation>
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation>Oran şu değere ulaştığında</translation>
    </message>
    <message>
        <source>sec</source>
        <translation>san</translation>
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation>Gönderim şu süreye ulaştığında</translation>
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation>Aynı IP adresinden çoklu bağlantılara izin ver:</translation>
    </message>
    <message>
        <source>File pool size:</source>
        <translation>Dosya havuzu boyutu:</translation>
    </message>
    <message>
        <source>Any interface</source>
        <translation>Herhangi bir arayüz</translation>
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation>Tüm katmanlara her zaman duyur:</translation>
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation>Gömülü izleyici bağlantı noktası:</translation>
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation>Bağlamak için isteğe bağlı IP Adresi (yeniden başlatma gerektirir):</translation>
    </message>
    <message>
        <source>Fastest upload</source>
        <translation>En hızlı gönderme</translation>
    </message>
    <message>
        <source>Pause torrent</source>
        <translation>Torrent'i duraklat</translation>
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation>Torrent'i ve dosyalarını kaldır</translation>
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation>qBittorrent Bölümü</translation>
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation>Gönderme arabelleği eşiği etkeni:</translation>
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation>libtorrent Bölümü</translation>
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation>Okuma ve yazmaları birleştir:</translation>
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation>Giden b.noktaları (En az) [0: Etkisizleştirildi]:</translation>
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation>İzleyicilere bildirmek için IP Adresi (yeniden başlatma gerektirir):</translation>
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation>Tamamlanmada torrent'leri yeniden denetle:</translation>
    </message>
    <message>
        <source>Allow encryption</source>
        <translation>Şifrelemeye izin ver</translation>
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation>Gönderme parçası önerileri gönder:</translation>
    </message>
    <message>
        <source>Disk cache:</source>
        <translation>Disk önbelleği:</translation>
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation>Gömülü izleyiciyi etkinleştir:</translation>
    </message>
    <message>
        <source>Remove torrent</source>
        <translation>Torrent'i kaldır</translation>
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation>Giden b.noktaları (En fazla) [0: Etkisizleştirildi]:</translation>
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation>Eşzamansız G/Ç iş parçaları:</translation>
    </message>
    <message>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation>Gönderme arabelleği eşiği:</translation>
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation>Disk önbelleği bitiş aralığı:</translation>
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation>Kişi orantılı (TCP'yi kısıtlar)</translation>
    </message>
    <message>
        <source>Fixed slots</source>
        <translation>Sabit yuvalar</translation>
    </message>
    <message>
        <source>Resolve peer countries (GeoIP):</source>
        <translation>Kişi ülkelerini çöz (GeoIP):</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <source>min</source>
        <translation>dak</translation>
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation>Gönderme kısma algoritması:</translation>
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation>Gönderim Sınırları</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>Round-robin</source>
        <translation>Dönüşümlü</translation>
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation>Gönderme yuvaları davranışı:</translation>
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation>Ağ Arayüzü (yeniden başlatma gerektirir):</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation>Gönderme arabelleği alt eşiği:</translation>
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation>Devam etme verisi kaydetme aralığı:</translation>
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation>Bir katmandaki tüm izleyicilere her zaman duyur:</translation>
    </message>
    <message>
        <source>Session timeout:</source>
        <translation>Oturum zaman aşımı:</translation>
    </message>
    <message>
        <source>Listen on IPv6 address (requires restart):</source>
        <translation>IPv6 adresinde dinle (yeniden başlatma gerektirir):</translation>
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>B.Noktası</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>İşaretler</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Bağlantı</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>İstemci</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>İlerleme</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>İnd. Hızı</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Gön. Hızı</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>İndirilen</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Gönderilen</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Uygunluk</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Dosyalar</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Ülke</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation>Kişiyi kalıcı olarak yasakla</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation>Seçilen kişileri kalıcı olarak yasaklamak istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation>IP:b.noktasını kopyala</translation>
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation>Yeni bir kişi ekle...</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Yüksek</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>En yüksek</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation>Karışık</translation>
    </message>
    <message>
        <source>Do not download</source>
        <translation>İndirme yapma</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>İzleyiciler</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Kişiler</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP Kaynakları</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>İçerik</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>İndirilen:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Aktarım</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Etkinlik Süresi:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>TBS:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Gönderilen:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Gönderim:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>İndirme Hızı:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Gönderme Hızı:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Kişi:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>İndirme Sınırı:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Gönderme Sınırı:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Boşa Giden:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Bağlantı:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Paylaşma Oranı:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Yeniden Duyuru Süresi:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Tam Halinin Görülmesi:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Toplam Boyut:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Parça:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Oluşturan:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Eklenme:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Tamamlanma:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Oluşturma:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent Adreslemesi:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Kaydetme Yolu:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Asla</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (%3 var)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (bu oturumda %2)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (en fazla %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (toplam %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (ort. %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>İndirme sınırı:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Gönderme sınırı:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Öncelik</translation>
    </message>
    <message>
        <source>Filter files...</source>
        <translation>Dosyaları süzün...</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>İzlenen Klasör</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Geçersiz Kılınan Kaydetme Yeri</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>İzlenen klasör</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Varsayılan kaydetme yeri</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>İstatistikler</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Kullanıcı istatistikleri</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Önbellek istatistikleri</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Okuma önbelleği yoklaması:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Kuyruktaki ortalama süre:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Bağlı kişi:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Tüm zaman paylaşma oranı:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Tüm zaman indirilen:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Oturum israfı:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Tüm zaman gönderilen:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Toplam arabellek boyutu:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Performans istatistikleri</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Kuyruğa alınmış G/Ç işi:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Yazma önbelleği aşırı yükü:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Okuma önbelleği aşırı yükü:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Toplam kuyruğa alınmış boyut:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 düğüm</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Tümü (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>İndiriliyor (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Gönderiliyor (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Tamamlandı (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Devam edildi (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Duraklatıldı (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Etkin (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Etkin değil (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Hata oldu (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Tümü (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>İndiriliyor (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Gönderiliyor (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Tamamlandı (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Duraklatıldı (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Devam edildi (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Etkin (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Etkin değil (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Hata oldu (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Tamamlanma</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Gönderim</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Kişi</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>İnd. Hızı</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Gön. Hızı</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Oran</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>TBS</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Eklenme</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Tamamlanma</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>İzleyici</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>İnd. Sınırı</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Gön. Sınırı</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>İndirilen</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Gönderilen</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Oturumda İndirilen</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Oturumda Gönderilen</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Kalan</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Etkinlik Süresi</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Kaydetme yolu</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Tamamlanan</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Oran Sınırı</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Tam Halinin Görülmesi</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Son Etkinlik</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Toplam Boyut</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Kullanılabilirlik</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Kişi</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>İleti</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>İndiren</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>İzleyici URL'si:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Güncelleniyor...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Çalışıyor</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Etkisizleştirildi</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Daha bağlanmadı</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Gönderim</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Çalışmıyor</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>İzleyici URL'sini kopyala</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Yeni bir izleyici ekle...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>İzleyici URL'sini düzenle...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>İzleyici düzenleme</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Çekme</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>İzleyiciyi kaldır</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Kalan</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Kullanılabilirlik</translation>
    </message>
    <message>
        <source>Tier</source>
        <translation>Katman</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>İndirme Önceliği</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>İlerleme</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>İzleyicileri ekleme ileti penceresi</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Eklemek için izleyicilerin listesi (her satıra bir tane):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 önce</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Ayrılıyor</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Duraklatıldı</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Tamamlanan</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Taşınıyor</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Gönderiliyor</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Gönderiliyor</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Kuyrukta</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Hata oldu</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] İndiriliyor</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Üstveri indiriliyor</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Denetleniyor</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Eksik Dosyalar</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Denetim için kuyruğa alındı</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>İndiriliyor</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Devam etme verisi denetleniyor</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Askıda</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategoriler</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrent İndirme Hızı Sınırlama</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrent Gönderme Hızı Sınırlama</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Yeniden adlandır</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Devam</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Devam Etmeye Zorla</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Paylaşma oranını sınırla...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Gönderme oranını sınırla...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>İndirme oranını sınırla...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Yukarı taşı</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Aşağı taşı</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>En üste taşı</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>En alta taşı</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Yeri ayarla...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Önce ilk ve son parçaları indir</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Otomatik Torrent Yönetimi</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Yeni...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Sıfırla</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Yeniden denetlemeye zorla</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Süper gönderim kipi</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Yeniden adlandır...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Sıralı düzende indir</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Yeniden Denetlemeye Zorla</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Yeni Kategori</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Yeni adı</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Yeri ayarla</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Yeniden duyurmaya zorla</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Kategoriyi Düzenle</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Kaydetme yolu</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation>Virgülle ayrılmış etiketler:</translation>
    </message>
    <message>
        <source>Add Tags</source>
        <translation>Etiketleri Ekle</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketler</translation>
    </message>
    <message>
        <source>Magnet link</source>
        <translation>Magnet bağlantısı</translation>
    </message>
    <message>
        <source>Hash</source>
        <translation>Adresleme</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Tümünü Kaldır</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Queue</source>
        <translation>Kuyruk</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Ekle...</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrent Gönderme/İndirme Oranı Sınırlama</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Genel paylaşma sınırını kullan</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Paylaşma sınırını ayarlama</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Paylaşma sınırını şuna ayarla</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>oran</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>dakika</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Silme onayı</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Aynı zamanda sabit diskteki dosyaları sil</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Silme onayı - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>URL'lerden indir</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Torrent Bağlantıları Ekle</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1sa %2dk</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1gn %2sa</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Bilinmiyor</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1dk</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1dk</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Kaydetme yolu boş</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Eklenti yolu:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL veya yerel dizin</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Eklenti yükle</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Gönderim:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Tüm eklentiler</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Boyut:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Arama eklentileri...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Tüm kategoriler</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Aranan:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Sonuçlar (gösterilen</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Süz</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Sadece torrent adları</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Sadece etkinleştirilmişler</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>/</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Her yeri</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Kaldır</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Yeni eklenti yükle</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Yeni arama motoru eklentilerini buradan alabilirsiniz:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Yüklenmiş arama eklentileri:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Etkinleştirildi</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Uyarı: Bu arama motorlarının herhangi birinden torrent'leri indirirken ülkenizin telif hakkı yasalarına uyulduğundan emin olun.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Güncellemeleri denetle</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Arama eklentileri</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Çeken</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Arama motoru</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Gönderen</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Etkinleştirildi</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Sürüm</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Add Peers</source>
        <translation>Kişileri Ekle</translation>
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation>Eklemek için kişilerin listesi (her satıra bir IP):</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation>Biçim: IPv4:b.noktası / [IPv6]:b.noktası</translation>
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation>Yeni Etiket</translation>
    </message>
    <message>
        <source>Add tag...</source>
        <translation>Etiket ekle...</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Torrent'leri sil</translation>
    </message>
    <message>
        <source>Tag:</source>
        <translation>Etiket:</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Torrent'leri duraklat</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Torrent'lere devam et</translation>
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation>Kullanılmayan etiketleri kaldır</translation>
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation>Geçersiz etiket adı</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Etiketi kaldır</translation>
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Etiketlenmemiş</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation>Hata İzleyicisi:</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-posta:</translation>
    </message>
    <message>
        <source>Current maintainer</source>
        <translation>Şu anki geliştiren</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Ana Sayfa:</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Yunanistan</translation>
    </message>
    <message>
        <source>Special Thanks</source>
        <translation>Özel Teşekkürler</translation>
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Qt toolkit ve libtorrent-rasterbar tabanlı, C++ ile programlanmış gelişmiş bir BitTorrent istemcisidir.</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Adı:</translation>
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation>qBittorrent Hakkında</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Kütüphaneler</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Çevirmenler</translation>
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation>qBittorrent aşağıdaki kütüphaneler ile yapıldı:</translation>
    </message>
    <message>
        <source>Nationality:</source>
        <translation>Uyruk:</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Hazırlayan</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation>Tüm adresler</translation>
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Adı</translation>
    </message>
    <message>
        <source>Description page URL</source>
        <translation>Açıklama sayfası URL'si</translation>
    </message>
    <message>
        <source>Open description page</source>
        <translation>Açıklama sayfasını aç</translation>
    </message>
    <message>
        <source>Download link</source>
        <translation>İndirme bağlantısı</translation>
    </message>
</context>
</TS>